@@ -155,224 +155,13 @@ print(f"Server.py 当前工作目录: {os.getcwd()}")
 mcp = FastMCP("Interactive Feedback MCP", log_level="ERROR")
 
 
-def detect_uvx_environment() -> bool:
-    """检测是否在 uvx 环境中运行"""
-    return (
-        'UV_PROJECT_ENVIRONMENT' in os.environ or
-        'UV_CACHE_DIR' in os.environ or
-        'UV_TOOL_DIR' in os.environ
-    )
-
-
-def detect_mcp_environment() -> bool:
-    """检测是否在 MCP 服务环境中运行"""
-    return (
-        not sys.stdin.isatty() or  # 没有交互式终端
-        'MCP_SERVER' in os.environ or
-        hasattr(sys.stdin, 'closed') and sys.stdin.closed
-    )
-
-
-def launch_feedback_ui_via_module(
-    summary: str, predefined_options_list: Optional[List[str]] = None
-) -> Dict[str, Any]:
-    """
-    通过直接模块调用启动 feedback UI（uvx 兼容模式）
-    Launch feedback UI via direct module call (uvx compatible mode)
-    """
-    tmp_file_path = None
-    try:
-        # 创建输出文件
-        with tempfile.NamedTemporaryFile(
-            suffix=".json", delete=False, mode="w", encoding="utf-8"
-        ) as tmp:
-            tmp_file_path = tmp.name
-
-        options_str = (
-            "|||".join(predefined_options_list) if predefined_options_list else ""
-        )
-
-        # 尝试直接导入并调用 feedback_ui
-        try:
-            # 检查PySide6是否可用
-            try:
-                import PySide6
-                print(f"PySide6 版本: {PySide6.__version__}", file=sys.stderr)
-
-                # 在MCP环境中，即使PySide6可用也不能启动GUI
-                if detect_mcp_environment():
-                    print("检测到MCP环境，跳过GUI启动", file=sys.stderr)
-                    raise ImportError("MCP环境不支持GUI")
-
-            except ImportError as pyside_error:
-                print(f"警告: PySide6 不可用或不适用: {pyside_error}", file=sys.stderr)
-                print("将使用降级模式", file=sys.stderr)
-                raise ImportError("PySide6 不可用")
-
-            from feedback_ui.cli import start_feedback_tool
-
-            options_list = [
-                opt.strip() for opt in options_str.split("|||") if opt.strip()
-            ] if options_str else None
-
-            print(f"使用模块直接调用模式启动 UI", file=sys.stderr)
-            result = start_feedback_tool(summary, options_list, tmp_file_path)
-
-            # 读取结果文件
-            with open(tmp_file_path, "r", encoding="utf-8") as f:
-                ui_result_data = json.load(f)
-
-            return ui_result_data
-
-        except ImportError as import_error:
-            print(f"模块导入失败: {import_error}", file=sys.stderr)
-            print("可能原因: PySide6依赖在uvx环境中不完整或MCP环境不支持GUI", file=sys.stderr)
-            # 降级到命令行模式
-            raise Exception("模块导入失败，需要降级处理")
-
-    except Exception as e:
-        print(f"错误: launch_feedback_ui_via_module 异常: {e}", file=sys.stderr)
-        raise
-    finally:
-        # 清理临时文件
-        if tmp_file_path and os.path.exists(tmp_file_path):
-            try:
-                os.unlink(tmp_file_path)
-            except OSError as e_unlink:
-                print(
-                    f"警告: 删除临时文件失败 '{tmp_file_path}': {e_unlink}",
-                    file=sys.stderr,
-                )
-
-
-def launch_feedback_ui_fallback(
-    summary: str, predefined_options_list: Optional[List[str]] = None
-) -> Dict[str, Any]:
-    """
-    降级模式：使用简化的命令行交互或MCP兼容模式
-    Fallback mode: use simplified command line interaction or MCP compatible mode
-    """
-    # 检测是否在MCP环境中
-    is_mcp = detect_mcp_environment()
-
-    if is_mcp:
-        # MCP环境：无法进行交互式输入，返回默认选项或提示
-        print("🔄 MCP环境检测：无交互式终端，使用智能默认选择", file=sys.stderr)
-
-        options_list = predefined_options_list or []
-
-        if options_list:
-            # 如果有预定义选项，选择第一个作为默认
-            user_input = options_list[0]
-            print(f"📋 自动选择第一个选项: {user_input}", file=sys.stderr)
-        else:
-            # 没有预定义选项，返回一个通用的确认
-            user_input = "继续执行"
-            print(f"📝 AI请求: {summary}", file=sys.stderr)
-            print(f"✅ 自动确认: {user_input}", file=sys.stderr)
-
-        result = {
-            "content": [
-                {
-                    "type": "text",
-                    "text": user_input
-                }
-            ],
-            "metadata": {
-                "mode": "mcp_auto",
-                "environment": "mcp_fallback",
-                "version": "2.5.6",
-                "auto_selected": True
-            }
-        }
-
-        return result
-
-    # 非MCP环境：使用交互式命令行
-    print("\n" + "="*60, file=sys.stderr)
-    print("🔄 uvx 兼容模式：简化命令行交互", file=sys.stderr)
-    print("💡 提示：GUI界面在uvx环境中不可用，使用命令行交互", file=sys.stderr)
-    print("="*60, file=sys.stderr)
-
-    # 解析选项
-    options_list = predefined_options_list or []
-
-    # 创建简化的交互
-    print(f"\n📝 AI助手请求:", file=sys.stderr)
-    print(f"   {summary}", file=sys.stderr)
-
-    if options_list:
-        print(f"\n📋 可选选项:", file=sys.stderr)
-        for i, option in enumerate(options_list, 1):
-            print(f"   {i}. {option}", file=sys.stderr)
-        print(f"   {len(options_list) + 1}. 💬 自定义输入", file=sys.stderr)
-
-        try:
-            choice = input(f"\n👆 请选择 (1-{len(options_list) + 1}): ").strip()
-            choice_num = int(choice)
-
-            if 1 <= choice_num <= len(options_list):
-                user_input = options_list[choice_num - 1]
-                print(f"✅ 您选择了: {user_input}", file=sys.stderr)
-            else:
-                user_input = input("💬 请输入您的反馈: ").strip()
-                print(f"✅ 您输入了: {user_input}", file=sys.stderr)
-        except (ValueError, KeyboardInterrupt, EOFError):
-            user_input = "用户取消操作"
-            print("❌ 操作已取消", file=sys.stderr)
-    else:
-        try:
-            user_input = input("\n💬 请输入您的反馈: ").strip()
-            if user_input:
-                print(f"✅ 您输入了: {user_input}", file=sys.stderr)
-        except (KeyboardInterrupt, EOFError):
-            user_input = "用户取消操作"
-            print("❌ 操作已取消", file=sys.stderr)
-
-    print("="*60 + "\n", file=sys.stderr)
-
-    # 创建结果
-    result = {
-        "content": [
-            {
-                "type": "text",
-                "text": user_input or "无反馈"
-            }
-        ],
-        "metadata": {
-            "mode": "fallback",
-            "environment": "uvx_fallback",
-            "version": "2.5.6"
-        }
-    }
-
-    return result
-
-
 def launch_feedback_ui(
     summary: str, predefined_options_list: Optional[List[str]] = None
 ) -> Dict[str, Any]:
     """
     Launches the feedback UI as a separate process using its command-line entry point.
     Collects user input and returns it as a structured dictionary.
-
-    修改版本：添加 uvx 环境检测和兼容性处理
-    Modified version: Added uvx environment detection and compatibility handling
     """
-    # 检测 uvx 环境
-    is_uvx = detect_uvx_environment()
-
-    if is_uvx:
-        print("检测到 uvx 环境，使用兼容模式", file=sys.stderr)
-        try:
-            # 尝试模块直接调用
-            return launch_feedback_ui_via_module(summary, predefined_options_list)
-        except Exception as module_error:
-            print(f"模块调用失败: {module_error}", file=sys.stderr)
-            print("降级到简化交互模式", file=sys.stderr)
-            return launch_feedback_ui_fallback(summary, predefined_options_list)
-
-    # 原始的命令行调用模式（非 uvx 环境）
     tmp_file_path = None
     try:
         # 创建输出文件
@@ -421,10 +210,7 @@ def launch_feedback_ui(
                 print(f"UI STDOUT:\n{process_result.stdout}", file=sys.stderr)
             if process_result.stderr:
                 print(f"UI STDERR:\n{process_result.stderr}", file=sys.stderr)
-
-            # 如果命令行调用失败，尝试降级模式
-            print("命令行调用失败，尝试降级模式", file=sys.stderr)
-            return launch_feedback_ui_fallback(summary, predefined_options_list)
+            raise Exception(f"启动反馈UI失败: {process_result.returncode}")
 
         with open(tmp_file_path, "r", encoding="utf-8") as f:
             ui_result_data = json.load(f)
@@ -433,12 +219,11 @@ def launch_feedback_ui(
 
     except FileNotFoundError:
         print("错误: 'feedback-ui' 命令未找到", file=sys.stderr)
-        print("尝试降级模式", file=sys.stderr)
-        return launch_feedback_ui_fallback(summary, predefined_options_list)
+        print("请确保项目已在可编辑模式下安装 (pip install -e .)", file=sys.stderr)
+        raise
     except Exception as e:
         print(f"错误: launch_feedback_ui 异常: {e}", file=sys.stderr)
-        print("尝试降级模式", file=sys.stderr)
-        return launch_feedback_ui_fallback(summary, predefined_options_list)
+        raise
     finally:
         # 清理临时文件
         if tmp_file_path and os.path.exists(tmp_file_path):
@@ -525,25 +310,18 @@ def interactive_feedback(
     return tuple(processed_mcp_content)
 
 
-@mcp.tool()
-def optimize_user_input(
-    original_text: str = Field(description="用户的原始输入文本"),
-    mode: str = Field(description="优化模式: 'optimize' 或 'reinforce'"),
-    reinforcement_prompt: Optional[str] = Field(
-        default=None, description="在 'reinforce' 模式下用户的自定义指令"
-    ),
+def _optimize_user_input_internal(
+    original_text: str,
+    mode: str,
+    reinforcement_prompt: Optional[str] = None,
 ) -> str:
     """
-    使用配置的 LLM API 来优化或强化用户输入的文本。
-
-    此功能可以帮助用户将口语化的、可能存在歧义的输入，转化为更结构化、
-    更清晰、更便于 AI 模型理解的文本。
+    内部优化函数，供GUI和MCP工具共同使用
+    Internal optimization function for both GUI and MCP tool usage
 
     Args:
         original_text: 用户的原始输入文本
-        mode: 优化模式
-            - 'optimize': 一键优化，使用预设的通用优化指令
-            - 'reinforce': 提示词强化，使用用户自定义的强化指令
+        mode: 优化模式 ('optimize' 或 'reinforce')
         reinforcement_prompt: 在 'reinforce' 模式下用户的自定义指令
 
     Returns:
@@ -599,6 +377,33 @@ def optimize_user_input(
         return f"[系统错误] 优化过程中发生异常: {e}"
 
 
+@mcp.tool()
+def optimize_user_input(
+    original_text: str = Field(description="用户的原始输入文本"),
+    mode: str = Field(description="优化模式: 'optimize' 或 'reinforce'"),
+    reinforcement_prompt: Optional[str] = Field(
+        default=None, description="在 'reinforce' 模式下用户的自定义指令"
+    ),
+) -> str:
+    """
+    使用配置的 LLM API 来优化或强化用户输入的文本。
+
+    此功能可以帮助用户将口语化的、可能存在歧义的输入，转化为更结构化、
+    更清晰、更便于 AI 模型理解的文本。
+
+    Args:
+        original_text: 用户的原始输入文本
+        mode: 优化模式
+            - 'optimize': 一键优化，使用预设的通用优化指令
+            - 'reinforce': 提示词强化，使用用户自定义的强化指令
+        reinforcement_prompt: 在 'reinforce' 模式下用户的自定义指令
+
+    Returns:
+        str: 优化后的文本或错误信息
+    """
+    return _optimize_user_input_internal(original_text, mode, reinforcement_prompt)
+
+
 def main():
     """Main function to run the MCP server."""
     mcp.run(transport="stdio")
